FileConflictPolicy

Enum FileConflictPolicy 

pub enum FileConflictPolicy {
    Error,
    Skip,
    Overwrite,
    OverwriteKeepingHistory,
}
Replacement policy for uploads targeting an existing file name.

Variants



Error

Return an error if the file already exists.



Skip

Skip uploads for files that already exist.



Overwrite

Overwrite the existing file in place.



OverwriteKeepingHistory

Overwrite the existing file while preserving its old version.