pub enum IdentifierError {
Empty,
TooLong {
identifier: String,
max: usize,
},
InvalidStartCharacter {
identifier: String,
character: char,
},
TooShortForBucketCreation {
identifier: String,
min: usize,
},
TooLongForBucketCreation {
identifier: String,
max: usize,
},
InvalidCharacter {
identifier: String,
character: char,
},
InvalidBucketCreationCharacter {
identifier: String,
character: char,
},
InvalidBucketCreationEdgeCharacter {
identifier: String,
character: char,
},
AdjacentBucketCreationPeriods {
identifier: String,
},
BucketCreationIdentifierLooksLikeIpAddress {
identifier: String,
},
PeriodAdjacentBucketCreationDash {
identifier: String,
},
}Expand description
Validation errors for ItemIdentifier.
Variants
Empty
Identifier was empty after trimming.
TooLong
Identifier exceeds Internet Archive’s documented maximum length.
Fields
InvalidStartCharacter
Identifier starts with an unsupported character.
Fields
TooShortForBucketCreation
Identifier is too short for Internet Archive’s S3 bucket-creation layer.
Fields
TooLongForBucketCreation
Identifier is too long for Internet Archive’s S3 bucket-creation layer.
Fields
InvalidCharacter
Identifier contains an unsupported character.
Fields
InvalidBucketCreationCharacter
Identifier contains a character that the conservative IA-S3 bucket creation subset rejects.
Fields
InvalidBucketCreationEdgeCharacter
Identifier starts or ends with a character that the conservative IA-S3 bucket-creation subset rejects.
Fields
AdjacentBucketCreationPeriods
Identifier contains adjacent periods that S3 bucket creation rejects.
BucketCreationIdentifierLooksLikeIpAddress
Identifier has the shape of an IPv4 address, which S3 bucket creation rejects.
PeriodAdjacentBucketCreationDash
Identifier contains a period adjacent to a dash, which S3-compatible bucket creation rejects.